==> haskell-openpgp-asciiarmor-0.1.2-341.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-14IjyIowAG8E8aK9z5osz5
key:                  openpgp-asciiarmor-0.1.2-14IjyIowAG8E8aK9z5osz5
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  3b0f8595a4f56335a04c3c6e4f2d86a9
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/openpgp-asciiarmor-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-14IjyIowAG8E8aK9z5osz5
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr binary-0.8.9.1
    bytestring-0.11.5.3

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.2-342-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-HyETLBbNKgl8y0nbPsG8mM
key:                  openpgp-asciiarmor-0.1.2-HyETLBbNKgl8y0nbPsG8mM
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  41edddad9734f0931f2d3679eae85cea
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/openpgp-asciiarmor-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-HyETLBbNKgl8y0nbPsG8mM
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh binary-0.8.9.1
    bytestring-0.11.5.3

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
